from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.node.v2 import node_pb2 as _node_pb2
from sentinel.node.v2 import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ["nodes", "params"]
    NODES_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedCompositeFieldContainer[_node_pb2.Node]
    params: _params_pb2.Params
    def __init__(self, nodes: _Optional[_Iterable[_Union[_node_pb2.Node, _Mapping]]] = ..., params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from cosmos.mint.v1beta1 import mint_pb2 as _mint_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryAnnualProvisionsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class QueryAnnualProvisionsResponse(_message.Message):
    __slots__ = ["annual_provisions"]
    ANNUAL_PROVISIONS_FIELD_NUMBER: _ClassVar[int]
    annual_provisions: bytes
    def __init__(self, annual_provisions: _Optional[bytes] = ...) -> None: ...

class QueryInflationRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class QueryInflationResponse(_message.Message):
    __slots__ = ["inflation"]
    INFLATION_FIELD_NUMBER: _ClassVar[int]
    inflation: bytes
    def __init__(self, inflation: _Optional[bytes] = ...) -> None: ...

class QueryParamsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ["params"]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _mint_pb2.Params
    def __init__(self, params: _Optional[_Union[_mint_pb2.Params, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/node/v2/lease.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1csentinel/node/v2/lease.proto\x12\x10sentinel.node.v2\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\"\x89\x01\n\x05Lease\x12\x12\n\x02id\x18\x01 \x01(\x04\x42\x06\xe2\xde\x1f\x02ID\x12\x14\n\x0cnode_address\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x03 \x01(\t\x12\r\n\x05hours\x18\x04 \x01(\x03\x12.\n\x05price\x18\x05 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x42\x37Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v2.lease_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\250\342\036\000\310\341\036\000'
  _LEASE.fields_by_name['id']._options = None
  _LEASE.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _LEASE.fields_by_name['price']._options = None
  _LEASE.fields_by_name['price']._serialized_options = b'\310\336\037\000'
  _LEASE._serialized_start=105
  _LEASE._serialized_end=242
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ["inactive_duration", "proof_verification_enabled"]
    INACTIVE_DURATION_FIELD_NUMBER: _ClassVar[int]
    PROOF_VERIFICATION_ENABLED_FIELD_NUMBER: _ClassVar[int]
    inactive_duration: _duration_pb2.Duration
    proof_verification_enabled: bool
    def __init__(self, inactive_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., proof_verification_enabled: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v2/msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"sentinel/subscription/v2/msg.proto\x12\x18sentinel.subscription.v2\x1a\x14gogoproto/gogo.proto\",\n\x10MsgCancelRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\"{\n\x0fMsgShareRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12=\n\x05\x62ytes\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\x81\x01\n\x15MsgUpdateQuotaRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12=\n\x05\x62ytes\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\x13\n\x11MsgCancelResponse\"\x12\n\x10MsgShareResponse\"\x18\n\x16MsgUpdateQuotaResponse2\xca\x02\n\nMsgService\x12\x64\n\tMsgCancel\x12*.sentinel.subscription.v2.MsgCancelRequest\x1a+.sentinel.subscription.v2.MsgCancelResponse\x12\x61\n\x08MsgShare\x12).sentinel.subscription.v2.MsgShareRequest\x1a*.sentinel.subscription.v2.MsgShareResponse\x12s\n\x0eMsgUpdateQuota\x12/.sentinel.subscription.v2.MsgUpdateQuotaRequest\x1a\x30.sentinel.subscription.v2.MsgUpdateQuotaResponseB?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v2.msg_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _MSGSHAREREQUEST.fields_by_name['bytes']._options = None
  _MSGSHAREREQUEST.fields_by_name['bytes']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _MSGUPDATEQUOTAREQUEST.fields_by_name['bytes']._options = None
  _MSGUPDATEQUOTAREQUEST.fields_by_name['bytes']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _MSGCANCELREQUEST._serialized_start=86
  _MSGCANCELREQUEST._serialized_end=130
  _MSGSHAREREQUEST._serialized_start=132
  _MSGSHAREREQUEST._serialized_end=255
  _MSGUPDATEQUOTAREQUEST._serialized_start=258
  _MSGUPDATEQUOTAREQUEST._serialized_end=387
  _MSGCANCELRESPONSE._serialized_start=389
  _MSGCANCELRESPONSE._serialized_end=408
  _MSGSHARERESPONSE._serialized_start=410
  _MSGSHARERESPONSE._serialized_end=428
  _MSGUPDATEQUOTARESPONSE._serialized_start=430
  _MSGUPDATEQUOTARESPONSE._serialized_end=454
  _MSGSERVICE._serialized_start=457
  _MSGSERVICE._serialized_end=787
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MsgCancelRequest(_message.Message):
    __slots__ = ["id"]
    FROM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ..., **kwargs) -> None: ...

class MsgCancelResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgShareRequest(_message.Message):
    __slots__ = ["address", "bytes", "id"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    bytes: str
    id: int
    def __init__(self, id: _Optional[int] = ..., address: _Optional[str] = ..., bytes: _Optional[str] = ..., **kwargs) -> None: ...

class MsgShareResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgUpdateQuotaRequest(_message.Message):
    __slots__ = ["address", "bytes", "id"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    bytes: str
    id: int
    def __init__(self, id: _Optional[int] = ..., address: _Optional[str] = ..., bytes: _Optional[str] = ..., **kwargs) -> None: ...

class MsgUpdateQuotaResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v2/subscription.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+sentinel/subscription/v2/subscription.proto\x12\x18sentinel.subscription.v2\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1esentinel/types/v1/status.proto\"\xa3\x01\n\x10\x42\x61seSubscription\x12\x12\n\x02id\x18\x01 \x01(\x04\x42\x06\xe2\xde\x1f\x02ID\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\t\x12)\n\x06status\x18\x03 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12\x37\n\tstatus_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\"\xab\x01\n\x10NodeSubscription\x12\x42\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32*.sentinel.subscription.v2.BaseSubscriptionB\x08\xd0\xde\x1f\x01\xc8\xde\x1f\x00\x12\x14\n\x0cnode_address\x18\x02 \x01(\t\x12\r\n\x05hours\x18\x03 \x01(\x03\x12.\n\x05price\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x82\x01\n\x10PlanSubscription\x12\x42\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32*.sentinel.subscription.v2.BaseSubscriptionB\x08\xd0\xde\x1f\x01\xc8\xde\x1f\x00\x12\x1b\n\x07plan_id\x18\x02 \x01(\x04\x42\n\xe2\xde\x1f\x06PlanID\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t*}\n\x10SubscriptionType\x12)\n\x10TYPE_UNSPECIFIED\x10\x00\x1a\x13\x8a\x9d \x0fTypeUnspecified\x12\x1b\n\tTYPE_NODE\x10\x01\x1a\x0c\x8a\x9d \x08TypeNode\x12\x1b\n\tTYPE_PLAN\x10\x02\x1a\x0c\x8a\x9d \x08TypePlan\x1a\x04\x88\xa3\x1e\x00\x42?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v2.subscription_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _SUBSCRIPTIONTYPE._options = None
  _SUBSCRIPTIONTYPE._serialized_options = b'\210\243\036\000'
  _SUBSCRIPTIONTYPE.values_by_name["TYPE_UNSPECIFIED"]._options = None
  _SUBSCRIPTIONTYPE.values_by_name["TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 \017TypeUnspecified'
  _SUBSCRIPTIONTYPE.values_by_name["TYPE_NODE"]._options = None
  _SUBSCRIPTIONTYPE.values_by_name["TYPE_NODE"]._serialized_options = b'\212\235 \010TypeNode'
  _SUBSCRIPTIONTYPE.values_by_name["TYPE_PLAN"]._options = None
  _SUBSCRIPTIONTYPE.values_by_name["TYPE_PLAN"]._serialized_options = b'\212\235 \010TypePlan'
  _BASESUBSCRIPTION.fields_by_name['id']._options = None
  _BASESUBSCRIPTION.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _BASESUBSCRIPTION.fields_by_name['status_at']._options = None
  _BASESUBSCRIPTION.fields_by_name['status_at']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _NODESUBSCRIPTION.fields_by_name['base']._options = None
  _NODESUBSCRIPTION.fields_by_name['base']._serialized_options = b'\320\336\037\001\310\336\037\000'
  _NODESUBSCRIPTION.fields_by_name['price']._options = None
  _NODESUBSCRIPTION.fields_by_name['price']._serialized_options = b'\310\336\037\000'
  _PLANSUBSCRIPTION.fields_by_name['base']._options = None
  _PLANSUBSCRIPTION.fields_by_name['base']._serialized_options = b'\320\336\037\001\310\336\037\000'
  _PLANSUBSCRIPTION.fields_by_name['plan_id']._options = None
  _PLANSUBSCRIPTION.fields_by_name['plan_id']._serialized_options = b'\342\336\037\006PlanID'
  _SUBSCRIPTIONTYPE._serialized_start=665
  _SUBSCRIPTIONTYPE._serialized_end=790
  _BASESUBSCRIPTION._serialized_start=193
  _BASESUBSCRIPTION._serialized_end=356
  _NODESUBSCRIPTION._serialized_start=359
  _NODESUBSCRIPTION._serialized_end=530
  _PLANSUBSCRIPTION._serialized_start=533
  _PLANSUBSCRIPTION._serialized_end=663
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/session/v2/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n sentinel/session/v2/events.proto\x12\x13sentinel.session.v2\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1esentinel/types/v1/status.proto\"u\n\nEventStart\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12\x1d\n\x04node\x18\x02 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"node\"\x12-\n\x0csubscription\x18\x03 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"subscription\"\"v\n\x0b\x45ventUpdate\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12\x1d\n\x04node\x18\x02 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"node\"\x12-\n\x0csubscription\x18\x03 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"subscription\"\"\xb7\x01\n\x0e\x45ventSetStatus\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12\x1d\n\x04node\x18\x02 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"node\"\x12-\n\x0csubscription\x18\x03 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"subscription\"\x12<\n\x06status\x18\x04 \x01(\x0e\x32\x19.sentinel.types.v1.StatusB\x11\xf2\xde\x1f\ryaml:\"status\"\"\xb5\x01\n\x08\x45ventPay\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12\x1d\n\x04node\x18\x02 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"node\"\x12-\n\x0csubscription\x18\x03 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"subscription\"\x12@\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x15\xf2\xde\x1f\ryaml:\"amount\"\xc8\xde\x1f\x00\x42:Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.session.v2.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/session/types\250\342\036\000\310\341\036\000'
  _EVENTSTART.fields_by_name['id']._options = None
  _EVENTSTART.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTSTART.fields_by_name['node']._options = None
  _EVENTSTART.fields_by_name['node']._serialized_options = b'\362\336\037\013yaml:\"node\"'
  _EVENTSTART.fields_by_name['subscription']._options = None
  _EVENTSTART.fields_by_name['subscription']._serialized_options = b'\362\336\037\023yaml:\"subscription\"'
  _EVENTUPDATE.fields_by_name['id']._options = None
  _EVENTUPDATE.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTUPDATE.fields_by_name['node']._options = None
  _EVENTUPDATE.fields_by_name['node']._serialized_options = b'\362\336\037\013yaml:\"node\"'
  _EVENTUPDATE.fields_by_name['subscription']._options = None
  _EVENTUPDATE.fields_by_name['subscription']._serialized_options = b'\362\336\037\023yaml:\"subscription\"'
  _EVENTSETSTATUS.fields_by_name['id']._options = None
  _EVENTSETSTATUS.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTSETSTATUS.fields_by_name['node']._options = None
  _EVENTSETSTATUS.fields_by_name['node']._serialized_options = b'\362\336\037\013yaml:\"node\"'
  _EVENTSETSTATUS.fields_by_name['subscription']._options = None
  _EVENTSETSTATUS.fields_by_name['subscription']._serialized_options = b'\362\336\037\023yaml:\"subscription\"'
  _EVENTSETSTATUS.fields_by_name['status']._options = None
  _EVENTSETSTATUS.fields_by_name['status']._serialized_options = b'\362\336\037\ryaml:\"status\"'
  _EVENTPAY.fields_by_name['id']._options = None
  _EVENTPAY.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTPAY.fields_by_name['node']._options = None
  _EVENTPAY.fields_by_name['node']._serialized_options = b'\362\336\037\013yaml:\"node\"'
  _EVENTPAY.fields_by_name['subscription']._options = None
  _EVENTPAY.fields_by_name['subscription']._serialized_options = b'\362\336\037\023yaml:\"subscription\"'
  _EVENTPAY.fields_by_name['amount']._options = None
  _EVENTPAY.fields_by_name['amount']._serialized_options = b'\362\336\037\ryaml:\"amount\"\310\336\037\000'
  _EVENTSTART._serialized_start=143
  _EVENTSTART._serialized_end=260
  _EVENTUPDATE._serialized_start=262
  _EVENTUPDATE._serialized_end=380
  _EVENTSETSTATUS._serialized_start=383
  _EVENTSETSTATUS._serialized_end=566
  _EVENTPAY._serialized_start=569
  _EVENTPAY._serialized_end=750
# @@protoc_insertion_point(module_scope)



from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
TYPE_NODE: SubscriptionType
TYPE_PLAN: SubscriptionType
TYPE_UNSPECIFIED: SubscriptionType

class BaseSubscription(_message.Message):
    __slots__ = ["account_address", "id", "status", "status_at"]
    ACCOUNT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    account_address: str
    id: int
    status: _status_pb2.Status
    status_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[int] = ..., account_address: _Optional[str] = ..., status: _Optional[_Union[_status_pb2.Status, str]] = ..., status_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class NodeSubscription(_message.Message):
    __slots__ = ["base", "hours", "node_address", "price"]
    BASE_FIELD_NUMBER: _ClassVar[int]
    HOURS_FIELD_NUMBER: _ClassVar[int]
    NODE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    base: BaseSubscription
    hours: int
    node_address: str
    price: _coin_pb2.Coin
    def __init__(self, base: _Optional[_Union[BaseSubscription, _Mapping]] = ..., node_address: _Optional[str] = ..., hours: _Optional[int] = ..., price: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class PlanSubscription(_message.Message):
    __slots__ = ["base", "denom", "plan_id"]
    BASE_FIELD_NUMBER: _ClassVar[int]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    PLAN_ID_FIELD_NUMBER: _ClassVar[int]
    base: BaseSubscription
    denom: str
    plan_id: int
    def __init__(self, base: _Optional[_Union[BaseSubscription, _Mapping]] = ..., plan_id: _Optional[int] = ..., denom: _Optional[str] = ...) -> None: ...

class SubscriptionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/node/v2/querier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
from sentinel.node.v2 import lease_pb2 as sentinel_dot_node_dot_v2_dot_lease__pb2
from sentinel.node.v2 import node_pb2 as sentinel_dot_node_dot_v2_dot_node__pb2
from sentinel.node.v2 import params_pb2 as sentinel_dot_node_dot_v2_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/node/v2/querier.proto\x12\x10sentinel.node.v2\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1esentinel/types/v1/status.proto\x1a\x1csentinel/node/v2/lease.proto\x1a\x1bsentinel/node/v2/node.proto\x1a\x1dsentinel/node/v2/params.proto\"z\n\x11QueryNodesRequest\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8d\x01\n\x18QueryNodesForPlanRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"#\n\x10QueryNodeRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"P\n\x12QueryLeasesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"k\n\x1cQueryLeasesForAccountRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"h\n\x19QueryLeasesForNodeRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x1f\n\x11QueryLeaseRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"\x14\n\x12QueryParamsRequest\"~\n\x12QueryNodesResponse\x12+\n\x05nodes\x18\x01 \x03(\x0b\x32\x16.sentinel.node.v2.NodeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x85\x01\n\x19QueryNodesForPlanResponse\x12+\n\x05nodes\x18\x01 \x03(\x0b\x32\x16.sentinel.node.v2.NodeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"?\n\x11QueryNodeResponse\x12*\n\x04node\x18\x01 \x01(\x0b\x32\x16.sentinel.node.v2.NodeB\x04\xc8\xde\x1f\x00\"\x81\x01\n\x13QueryLeasesResponse\x12-\n\x06leases\x18\x01 \x03(\x0b\x32\x17.sentinel.node.v2.LeaseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x8b\x01\n\x1dQueryLeasesForAccountResponse\x12-\n\x06leases\x18\x01 \x03(\x0b\x32\x17.sentinel.node.v2.LeaseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x88\x01\n\x1aQueryLeasesForNodeResponse\x12-\n\x06leases\x18\x01 \x03(\x0b\x32\x17.sentinel.node.v2.LeaseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"B\n\x12QueryLeaseResponse\x12,\n\x05lease\x18\x01 \x01(\x0b\x32\x17.sentinel.node.v2.LeaseB\x04\xc8\xde\x1f\x00\"E\n\x13QueryParamsResponse\x12.\n\x06params\x18\x01 \x01(\x0b\x32\x18.sentinel.node.v2.ParamsB\x04\xc8\xde\x1f\x00\x32\xc2\x08\n\x0cQueryService\x12p\n\nQueryNodes\x12#.sentinel.node.v2.QueryNodesRequest\x1a$.sentinel.node.v2.QueryNodesResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/sentinel/nodes\x12\x90\x01\n\x11QueryNodesForPlan\x12*.sentinel.node.v2.QueryNodesForPlanRequest\x1a+.sentinel.node.v2.QueryNodesForPlanResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/sentinel/plans/{id}/nodes\x12w\n\tQueryNode\x12\".sentinel.node.v2.QueryNodeRequest\x1a#.sentinel.node.v2.QueryNodeResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/sentinel/nodes/{address}\x12t\n\x0bQueryLeases\x12$.sentinel.node.v2.QueryLeasesRequest\x1a%.sentinel.node.v2.QueryLeasesResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/sentinel/leases\x12\xa5\x01\n\x15QueryLeasesForAccount\x12..sentinel.node.v2.QueryLeasesForAccountRequest\x1a/.sentinel.node.v2.QueryLeasesForAccountResponse\"+\x82\xd3\xe4\x93\x02%\x12#/sentinel/accounts/{address}/leases\x12\x99\x01\n\x12QueryLeasesForNode\x12+.sentinel.node.v2.QueryLeasesForNodeRequest\x1a,.sentinel.node.v2.QueryLeasesForNodeResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /sentinel/nodes/{address}/leases\x12v\n\nQueryLease\x12#.sentinel.node.v2.QueryLeaseRequest\x1a$.sentinel.node.v2.QueryLeaseResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/sentinel/leases/{id}\x12\x81\x01\n\x0bQueryParams\x12$.sentinel.node.v2.QueryParamsRequest\x1a%.sentinel.node.v2.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/sentinel/modules/node/paramsB7Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v2.querier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\250\342\036\000\310\341\036\000'
  _QUERYNODESRESPONSE.fields_by_name['nodes']._options = None
  _QUERYNODESRESPONSE.fields_by_name['nodes']._serialized_options = b'\310\336\037\000'
  _QUERYNODESFORPLANRESPONSE.fields_by_name['nodes']._options = None
  _QUERYNODESFORPLANRESPONSE.fields_by_name['nodes']._serialized_options = b'\310\336\037\000'
  _QUERYNODERESPONSE.fields_by_name['node']._options = None
  _QUERYNODERESPONSE.fields_by_name['node']._serialized_options = b'\310\336\037\000'
  _QUERYLEASESRESPONSE.fields_by_name['leases']._options = None
  _QUERYLEASESRESPONSE.fields_by_name['leases']._serialized_options = b'\310\336\037\000'
  _QUERYLEASESFORACCOUNTRESPONSE.fields_by_name['leases']._options = None
  _QUERYLEASESFORACCOUNTRESPONSE.fields_by_name['leases']._serialized_options = b'\310\336\037\000'
  _QUERYLEASESFORNODERESPONSE.fields_by_name['leases']._options = None
  _QUERYLEASESFORNODERESPONSE.fields_by_name['leases']._serialized_options = b'\310\336\037\000'
  _QUERYLEASERESPONSE.fields_by_name['lease']._options = None
  _QUERYLEASERESPONSE.fields_by_name['lease']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYSERVICE.methods_by_name['QueryNodes']._options = None
  _QUERYSERVICE.methods_by_name['QueryNodes']._serialized_options = b'\202\323\344\223\002\021\022\017/sentinel/nodes'
  _QUERYSERVICE.methods_by_name['QueryNodesForPlan']._options = None
  _QUERYSERVICE.methods_by_name['QueryNodesForPlan']._serialized_options = b'\202\323\344\223\002\034\022\032/sentinel/plans/{id}/nodes'
  _QUERYSERVICE.methods_by_name['QueryNode']._options = None
  _QUERYSERVICE.methods_by_name['QueryNode']._serialized_options = b'\202\323\344\223\002\033\022\031/sentinel/nodes/{address}'
  _QUERYSERVICE.methods_by_name['QueryLeases']._options = None
  _QUERYSERVICE.methods_by_name['QueryLeases']._serialized_options = b'\202\323\344\223\002\022\022\020/sentinel/leases'
  _QUERYSERVICE.methods_by_name['QueryLeasesForAccount']._options = None
  _QUERYSERVICE.methods_by_name['QueryLeasesForAccount']._serialized_options = b'\202\323\344\223\002%\022#/sentinel/accounts/{address}/leases'
  _QUERYSERVICE.methods_by_name['QueryLeasesForNode']._options = None
  _QUERYSERVICE.methods_by_name['QueryLeasesForNode']._serialized_options = b'\202\323\344\223\002\"\022 /sentinel/nodes/{address}/leases'
  _QUERYSERVICE.methods_by_name['QueryLease']._options = None
  _QUERYSERVICE.methods_by_name['QueryLease']._serialized_options = b'\202\323\344\223\002\027\022\025/sentinel/leases/{id}'
  _QUERYSERVICE.methods_by_name['QueryParams']._options = None
  _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\202\323\344\223\002\037\022\035/sentinel/modules/node/params'
  _QUERYNODESREQUEST._serialized_start=270
  _QUERYNODESREQUEST._serialized_end=392
  _QUERYNODESFORPLANREQUEST._serialized_start=395
  _QUERYNODESFORPLANREQUEST._serialized_end=536
  _QUERYNODEREQUEST._serialized_start=538
  _QUERYNODEREQUEST._serialized_end=573
  _QUERYLEASESREQUEST._serialized_start=575
  _QUERYLEASESREQUEST._serialized_end=655
  _QUERYLEASESFORACCOUNTREQUEST._serialized_start=657
  _QUERYLEASESFORACCOUNTREQUEST._serialized_end=764
  _QUERYLEASESFORNODEREQUEST._serialized_start=766
  _QUERYLEASESFORNODEREQUEST._serialized_end=870
  _QUERYLEASEREQUEST._serialized_start=872
  _QUERYLEASEREQUEST._serialized_end=903
  _QUERYPARAMSREQUEST._serialized_start=905
  _QUERYPARAMSREQUEST._serialized_end=925
  _QUERYNODESRESPONSE._serialized_start=927
  _QUERYNODESRESPONSE._serialized_end=1053
  _QUERYNODESFORPLANRESPONSE._serialized_start=1056
  _QUERYNODESFORPLANRESPONSE._serialized_end=1189
  _QUERYNODERESPONSE._serialized_start=1191
  _QUERYNODERESPONSE._serialized_end=1254
  _QUERYLEASESRESPONSE._serialized_start=1257
  _QUERYLEASESRESPONSE._serialized_end=1386
  _QUERYLEASESFORACCOUNTRESPONSE._serialized_start=1389
  _QUERYLEASESFORACCOUNTRESPONSE._serialized_end=1528
  _QUERYLEASESFORNODERESPONSE._serialized_start=1531
  _QUERYLEASESFORNODERESPONSE._serialized_end=1667
  _QUERYLEASERESPONSE._serialized_start=1669
  _QUERYLEASERESPONSE._serialized_end=1735
  _QUERYPARAMSRESPONSE._serialized_start=1737
  _QUERYPARAMSRESPONSE._serialized_end=1806
  _QUERYSERVICE._serialized_start=1809
  _QUERYSERVICE._serialized_end=2899
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/plan/v2/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsentinel/plan/v2/events.proto\x12\x10sentinel.plan.v2\x1a\x14gogoproto/gogo.proto\x1a\x1esentinel/types/v1/status.proto\"e\n\x0b\x45ventCreate\x12\x1f\n\x02id\x18\x01 \x01(\x04\x42\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:\"id\"\x12\x35\n\x10provider_address\x18\x02 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"provider_address\"\"\xa9\x01\n\x11\x45ventUpdateStatus\x12\x1f\n\x02id\x18\x01 \x01(\x04\x42\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:\"id\"\x12\x35\n\x10provider_address\x18\x02 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"provider_address\"\x12<\n\x06status\x18\x03 \x01(\x0e\x32\x19.sentinel.types.v1.StatusB\x11\xf2\xde\x1f\ryaml:\"status\"\"\x96\x01\n\rEventLinkNode\x12\x1f\n\x02id\x18\x01 \x01(\x04\x42\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:\"id\"\x12-\n\x0cnode_address\x18\x02 \x01(\tB\x17\xf2\xde\x1f\x13yaml:\"node_address\"\x12\x35\n\x10provider_address\x18\x03 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"provider_address\"\"\x98\x01\n\x0f\x45ventUnlinkNode\x12\x1f\n\x02id\x18\x01 \x01(\x04\x42\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:\"id\"\x12-\n\x0cnode_address\x18\x02 \x01(\tB\x17\xf2\xde\x1f\x13yaml:\"node_address\"\x12\x35\n\x10provider_address\x18\x03 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"provider_address\"B7Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.plan.v2.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/plan/types\250\342\036\000\310\341\036\000'
  _EVENTCREATE.fields_by_name['id']._options = None
  _EVENTCREATE.fields_by_name['id']._serialized_options = b'\342\336\037\002ID\362\336\037\tyaml:\"id\"'
  _EVENTCREATE.fields_by_name['provider_address']._options = None
  _EVENTCREATE.fields_by_name['provider_address']._serialized_options = b'\362\336\037\027yaml:\"provider_address\"'
  _EVENTUPDATESTATUS.fields_by_name['id']._options = None
  _EVENTUPDATESTATUS.fields_by_name['id']._serialized_options = b'\342\336\037\002ID\362\336\037\tyaml:\"id\"'
  _EVENTUPDATESTATUS.fields_by_name['provider_address']._options = None
  _EVENTUPDATESTATUS.fields_by_name['provider_address']._serialized_options = b'\362\336\037\027yaml:\"provider_address\"'
  _EVENTUPDATESTATUS.fields_by_name['status']._options = None
  _EVENTUPDATESTATUS.fields_by_name['status']._serialized_options = b'\362\336\037\ryaml:\"status\"'
  _EVENTLINKNODE.fields_by_name['id']._options = None
  _EVENTLINKNODE.fields_by_name['id']._serialized_options = b'\342\336\037\002ID\362\336\037\tyaml:\"id\"'
  _EVENTLINKNODE.fields_by_name['node_address']._options = None
  _EVENTLINKNODE.fields_by_name['node_address']._serialized_options = b'\362\336\037\023yaml:\"node_address\"'
  _EVENTLINKNODE.fields_by_name['provider_address']._options = None
  _EVENTLINKNODE.fields_by_name['provider_address']._serialized_options = b'\362\336\037\027yaml:\"provider_address\"'
  _EVENTUNLINKNODE.fields_by_name['id']._options = None
  _EVENTUNLINKNODE.fields_by_name['id']._serialized_options = b'\342\336\037\002ID\362\336\037\tyaml:\"id\"'
  _EVENTUNLINKNODE.fields_by_name['node_address']._options = None
  _EVENTUNLINKNODE.fields_by_name['node_address']._serialized_options = b'\362\336\037\023yaml:\"node_address\"'
  _EVENTUNLINKNODE.fields_by_name['provider_address']._options = None
  _EVENTUNLINKNODE.fields_by_name['provider_address']._serialized_options = b'\362\336\037\027yaml:\"provider_address\"'
  _EVENTCREATE._serialized_start=105
  _EVENTCREATE._serialized_end=206
  _EVENTUPDATESTATUS._serialized_start=209
  _EVENTUPDATESTATUS._serialized_end=378
  _EVENTLINKNODE._serialized_start=381
  _EVENTLINKNODE._serialized_end=531
  _EVENTUNLINKNODE._serialized_start=534
  _EVENTUNLINKNODE._serialized_end=686
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EventAddQuota(_message.Message):
    __slots__ = ["address", "id"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    id: int
    def __init__(self, id: _Optional[int] = ..., address: _Optional[str] = ...) -> None: ...

class EventSetStatus(_message.Message):
    __slots__ = ["id", "status"]
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    id: int
    status: _status_pb2.Status
    def __init__(self, id: _Optional[int] = ..., status: _Optional[_Union[_status_pb2.Status, str]] = ...) -> None: ...

class EventSubscribe(_message.Message):
    __slots__ = ["id", "node", "plan"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_FIELD_NUMBER: _ClassVar[int]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    id: int
    node: str
    plan: int
    def __init__(self, id: _Optional[int] = ..., node: _Optional[str] = ..., plan: _Optional[int] = ...) -> None: ...

class EventUpdateQuota(_message.Message):
    __slots__ = ["address", "id"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    id: int
    def __init__(self, id: _Optional[int] = ..., address: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from interchain_security.ccv.consumer.v1 import query_pb2 as interchain__security_dot_ccv_dot_consumer_dot_v1_dot_query__pb2


class QueryStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.QueryNextFeeDistribution = channel.unary_unary(
                '/interchain_security.ccv.consumer.v1.Query/QueryNextFeeDistribution',
                request_serializer=interchain__security_dot_ccv_dot_consumer_dot_v1_dot_query__pb2.QueryNextFeeDistributionEstimateRequest.SerializeToString,
                response_deserializer=interchain__security_dot_ccv_dot_consumer_dot_v1_dot_query__pb2.QueryNextFeeDistributionEstimateResponse.FromString,
                )


class QueryServicer(object):
    """Missing associated documentation comment in .proto file."""

    def QueryNextFeeDistribution(self, request, context):
        """ConsumerGenesis queries the genesis state needed to start a consumer chain
        whose proposal has been accepted
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'QueryNextFeeDistribution': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryNextFeeDistribution,
                    request_deserializer=interchain__security_dot_ccv_dot_consumer_dot_v1_dot_query__pb2.QueryNextFeeDistributionEstimateRequest.FromString,
                    response_serializer=interchain__security_dot_ccv_dot_consumer_dot_v1_dot_query__pb2.QueryNextFeeDistributionEstimateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'interchain_security.ccv.consumer.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def QueryNextFeeDistribution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/interchain_security.ccv.consumer.v1.Query/QueryNextFeeDistribution',
            interchain__security_dot_ccv_dot_consumer_dot_v1_dot_query__pb2.QueryNextFeeDistributionEstimateRequest.SerializeToString,
            interchain__security_dot_ccv_dot_consumer_dot_v1_dot_query__pb2.QueryNextFeeDistributionEstimateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from sentinel.session.v2 import session_pb2 as _session_pb2
from sentinel.session.v2 import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ["params"]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    def __init__(self, params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class QuerySessionRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QuerySessionResponse(_message.Message):
    __slots__ = ["session"]
    SESSION_FIELD_NUMBER: _ClassVar[int]
    session: _session_pb2.Session
    def __init__(self, session: _Optional[_Union[_session_pb2.Session, _Mapping]] = ...) -> None: ...

class QuerySessionsForAccountRequest(_message.Message):
    __slots__ = ["address", "pagination"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, address: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QuerySessionsForAccountResponse(_message.Message):
    __slots__ = ["pagination", "sessions"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SESSIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    sessions: _containers.RepeatedCompositeFieldContainer[_session_pb2.Session]
    def __init__(self, sessions: _Optional[_Iterable[_Union[_session_pb2.Session, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QuerySessionsForNodeRequest(_message.Message):
    __slots__ = ["address", "pagination"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, address: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QuerySessionsForNodeResponse(_message.Message):
    __slots__ = ["pagination", "sessions"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SESSIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    sessions: _containers.RepeatedCompositeFieldContainer[_session_pb2.Session]
    def __init__(self, sessions: _Optional[_Iterable[_Union[_session_pb2.Session, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QuerySessionsForSubscriptionRequest(_message.Message):
    __slots__ = ["id", "pagination"]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    id: int
    pagination: _pagination_pb2.PageRequest
    def __init__(self, id: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QuerySessionsForSubscriptionResponse(_message.Message):
    __slots__ = ["pagination", "sessions"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SESSIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    sessions: _containers.RepeatedCompositeFieldContainer[_session_pb2.Session]
    def __init__(self, sessions: _Optional[_Iterable[_Union[_session_pb2.Session, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QuerySessionsRequest(_message.Message):
    __slots__ = ["pagination"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QuerySessionsResponse(_message.Message):
    __slots__ = ["pagination", "sessions"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SESSIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    sessions: _containers.RepeatedCompositeFieldContainer[_session_pb2.Session]
    def __init__(self, sessions: _Optional[_Iterable[_Union[_session_pb2.Session, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Lease(_message.Message):
    __slots__ = ["account_address", "hours", "id", "node_address", "price"]
    ACCOUNT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    HOURS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    account_address: str
    hours: int
    id: int
    node_address: str
    price: _coin_pb2.Coin
    def __init__(self, id: _Optional[int] = ..., node_address: _Optional[str] = ..., account_address: _Optional[str] = ..., hours: _Optional[int] = ..., price: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgRegisterRequest(_message.Message):
    __slots__ = ["description", "identity", "name", "website"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    WEBSITE_FIELD_NUMBER: _ClassVar[int]
    description: str
    identity: str
    name: str
    website: str
    def __init__(self, name: _Optional[str] = ..., identity: _Optional[str] = ..., website: _Optional[str] = ..., description: _Optional[str] = ..., **kwargs) -> None: ...

class MsgRegisterResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgUpdateRequest(_message.Message):
    __slots__ = ["description", "identity", "name", "status", "website"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    WEBSITE_FIELD_NUMBER: _ClassVar[int]
    description: str
    identity: str
    name: str
    status: _status_pb2.Status
    website: str
    def __init__(self, name: _Optional[str] = ..., identity: _Optional[str] = ..., website: _Optional[str] = ..., description: _Optional[str] = ..., status: _Optional[_Union[_status_pb2.Status, str]] = ..., **kwargs) -> None: ...

class MsgUpdateResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from cosmos.bank.v1beta1 import bank_pb2 as _bank_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryAllBalancesRequest(_message.Message):
    __slots__ = ["address", "pagination"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, address: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryAllBalancesResponse(_message.Message):
    __slots__ = ["balances", "pagination"]
    BALANCES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    balances: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, balances: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryBalanceRequest(_message.Message):
    __slots__ = ["address", "denom"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    address: str
    denom: str
    def __init__(self, address: _Optional[str] = ..., denom: _Optional[str] = ...) -> None: ...

class QueryBalanceResponse(_message.Message):
    __slots__ = ["balance"]
    BALANCE_FIELD_NUMBER: _ClassVar[int]
    balance: _coin_pb2.Coin
    def __init__(self, balance: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class QueryDenomMetadataRequest(_message.Message):
    __slots__ = ["denom"]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    denom: str
    def __init__(self, denom: _Optional[str] = ...) -> None: ...

class QueryDenomMetadataResponse(_message.Message):
    __slots__ = ["metadata"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _bank_pb2.Metadata
    def __init__(self, metadata: _Optional[_Union[_bank_pb2.Metadata, _Mapping]] = ...) -> None: ...

class QueryDenomsMetadataRequest(_message.Message):
    __slots__ = ["pagination"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryDenomsMetadataResponse(_message.Message):
    __slots__ = ["metadatas", "pagination"]
    METADATAS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    metadatas: _containers.RepeatedCompositeFieldContainer[_bank_pb2.Metadata]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, metadatas: _Optional[_Iterable[_Union[_bank_pb2.Metadata, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryParamsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ["params"]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _bank_pb2.Params
    def __init__(self, params: _Optional[_Union[_bank_pb2.Params, _Mapping]] = ...) -> None: ...

class QuerySpendableBalancesRequest(_message.Message):
    __slots__ = ["address", "pagination"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, address: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QuerySpendableBalancesResponse(_message.Message):
    __slots__ = ["balances", "pagination"]
    BALANCES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    balances: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, balances: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QuerySupplyOfRequest(_message.Message):
    __slots__ = ["denom"]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    denom: str
    def __init__(self, denom: _Optional[str] = ...) -> None: ...

class QuerySupplyOfResponse(_message.Message):
    __slots__ = ["amount"]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    amount: _coin_pb2.Coin
    def __init__(self, amount: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class QueryTotalSupplyRequest(_message.Message):
    __slots__ = ["pagination"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryTotalSupplyResponse(_message.Message):
    __slots__ = ["pagination", "supply"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SUPPLY_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    supply: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, supply: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/plan/v2/msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asentinel/plan/v2/msg.proto\x12\x10sentinel.plan.v2\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1esentinel/types/v1/status.proto\"\xf3\x01\n\x10MsgCreateRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12[\n\x06prices\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x35\n\x08validity\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\x98\xdf\x1f\x01\xc8\xde\x1f\x00\x12=\n\x05\x62ytes\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"e\n\x16MsgUpdateStatusRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04\x42\x06\xe2\xde\x1f\x02ID\x12)\n\x06status\x18\x03 \x01(\x0e\x32\x19.sentinel.types.v1.Status\"G\n\x12MsgLinkNodeRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04\x42\x06\xe2\xde\x1f\x02ID\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\"I\n\x14MsgUnlinkNodeRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04\x42\x06\xe2\xde\x1f\x02ID\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\"F\n\x13MsgSubscribeRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04\x42\x06\xe2\xde\x1f\x02ID\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\"\x13\n\x11MsgCreateResponse\"\x19\n\x17MsgUpdateStatusResponse\"\x15\n\x13MsgLinkNodeResponse\"\x17\n\x15MsgUnlinkNodeResponse\"\x16\n\x14MsgSubscribeResponse2\xe7\x03\n\nMsgService\x12T\n\tMsgCreate\x12\".sentinel.plan.v2.MsgCreateRequest\x1a#.sentinel.plan.v2.MsgCreateResponse\x12\x66\n\x0fMsgUpdateStatus\x12(.sentinel.plan.v2.MsgUpdateStatusRequest\x1a).sentinel.plan.v2.MsgUpdateStatusResponse\x12Z\n\x0bMsgLinkNode\x12$.sentinel.plan.v2.MsgLinkNodeRequest\x1a%.sentinel.plan.v2.MsgLinkNodeResponse\x12`\n\rMsgUnlinkNode\x12&.sentinel.plan.v2.MsgUnlinkNodeRequest\x1a\'.sentinel.plan.v2.MsgUnlinkNodeResponse\x12]\n\x0cMsgSubscribe\x12%.sentinel.plan.v2.MsgSubscribeRequest\x1a&.sentinel.plan.v2.MsgSubscribeResponseB7Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.plan.v2.msg_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/plan/types\250\342\036\000\310\341\036\000'
  _MSGCREATEREQUEST.fields_by_name['prices']._options = None
  _MSGCREATEREQUEST.fields_by_name['prices']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGCREATEREQUEST.fields_by_name['validity']._options = None
  _MSGCREATEREQUEST.fields_by_name['validity']._serialized_options = b'\230\337\037\001\310\336\037\000'
  _MSGCREATEREQUEST.fields_by_name['bytes']._options = None
  _MSGCREATEREQUEST.fields_by_name['bytes']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _MSGUPDATESTATUSREQUEST.fields_by_name['id']._options = None
  _MSGUPDATESTATUSREQUEST.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _MSGLINKNODEREQUEST.fields_by_name['id']._options = None
  _MSGLINKNODEREQUEST.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _MSGUNLINKNODEREQUEST.fields_by_name['id']._options = None
  _MSGUNLINKNODEREQUEST.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _MSGSUBSCRIBEREQUEST.fields_by_name['id']._options = None
  _MSGSUBSCRIBEREQUEST.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _MSGCREATEREQUEST._serialized_start=167
  _MSGCREATEREQUEST._serialized_end=410
  _MSGUPDATESTATUSREQUEST._serialized_start=412
  _MSGUPDATESTATUSREQUEST._serialized_end=513
  _MSGLINKNODEREQUEST._serialized_start=515
  _MSGLINKNODEREQUEST._serialized_end=586
  _MSGUNLINKNODEREQUEST._serialized_start=588
  _MSGUNLINKNODEREQUEST._serialized_end=661
  _MSGSUBSCRIBEREQUEST._serialized_start=663
  _MSGSUBSCRIBEREQUEST._serialized_end=733
  _MSGCREATERESPONSE._serialized_start=735
  _MSGCREATERESPONSE._serialized_end=754
  _MSGUPDATESTATUSRESPONSE._serialized_start=756
  _MSGUPDATESTATUSRESPONSE._serialized_end=781
  _MSGLINKNODERESPONSE._serialized_start=783
  _MSGLINKNODERESPONSE._serialized_end=804
  _MSGUNLINKNODERESPONSE._serialized_start=806
  _MSGUNLINKNODERESPONSE._serialized_end=829
  _MSGSUBSCRIBERESPONSE._serialized_start=831
  _MSGSUBSCRIBERESPONSE._serialized_end=853
  _MSGSERVICE._serialized_start=856
  _MSGSERVICE._serialized_end=1343
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/session/v2/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from sentinel.session.v2 import params_pb2 as sentinel_dot_session_dot_v2_dot_params__pb2
from sentinel.session.v2 import session_pb2 as sentinel_dot_session_dot_v2_dot_session__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!sentinel/session/v2/genesis.proto\x12\x13sentinel.session.v2\x1a\x14gogoproto/gogo.proto\x1a sentinel/session/v2/params.proto\x1a!sentinel/session/v2/session.proto\"w\n\x0cGenesisState\x12\x34\n\x08sessions\x18\x01 \x03(\x0b\x32\x1c.sentinel.session.v2.SessionB\x04\xc8\xde\x1f\x00\x12\x31\n\x06params\x18\x02 \x01(\x0b\x32\x1b.sentinel.session.v2.ParamsB\x04\xc8\xde\x1f\x00\x42:Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.session.v2.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/session/types\250\342\036\000\310\341\036\000'
  _GENESISSTATE.fields_by_name['sessions']._options = None
  _GENESISSTATE.fields_by_name['sessions']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=149
  _GENESISSTATE._serialized_end=268
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/session/v2/msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from sentinel.session.v2 import proof_pb2 as sentinel_dot_session_dot_v2_dot_proof__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsentinel/session/v2/msg.proto\x12\x13sentinel.session.v2\x1a\x14gogoproto/gogo.proto\x1a\x1fsentinel/session/v2/proof.proto\"D\n\x0fMsgStartRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04\x42\x06\xe2\xde\x1f\x02ID\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\"k\n\x17MsgUpdateDetailsRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12/\n\x05proof\x18\x02 \x01(\x0b\x32\x1a.sentinel.session.v2.ProofB\x04\xc8\xde\x1f\x00\x12\x11\n\tsignature\x18\x03 \x01(\x0c\"A\n\rMsgEndRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04\x42\x06\xe2\xde\x1f\x02ID\x12\x0e\n\x06rating\x18\x03 \x01(\x04\"\x12\n\x10MsgStartResponse\"\x1a\n\x18MsgUpdateDetailsResponse\"\x10\n\x0eMsgEndResponse2\xa9\x02\n\nMsgService\x12W\n\x08MsgStart\x12$.sentinel.session.v2.MsgStartRequest\x1a%.sentinel.session.v2.MsgStartResponse\x12o\n\x10MsgUpdateDetails\x12,.sentinel.session.v2.MsgUpdateDetailsRequest\x1a-.sentinel.session.v2.MsgUpdateDetailsResponse\x12Q\n\x06MsgEnd\x12\".sentinel.session.v2.MsgEndRequest\x1a#.sentinel.session.v2.MsgEndResponseB:Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.session.v2.msg_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/session/types\250\342\036\000\310\341\036\000'
  _MSGSTARTREQUEST.fields_by_name['id']._options = None
  _MSGSTARTREQUEST.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _MSGUPDATEDETAILSREQUEST.fields_by_name['proof']._options = None
  _MSGUPDATEDETAILSREQUEST.fields_by_name['proof']._serialized_options = b'\310\336\037\000'
  _MSGENDREQUEST.fields_by_name['id']._options = None
  _MSGENDREQUEST.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _MSGSTARTREQUEST._serialized_start=109
  _MSGSTARTREQUEST._serialized_end=177
  _MSGUPDATEDETAILSREQUEST._serialized_start=179
  _MSGUPDATEDETAILSREQUEST._serialized_end=286
  _MSGENDREQUEST._serialized_start=288
  _MSGENDREQUEST._serialized_end=353
  _MSGSTARTRESPONSE._serialized_start=355
  _MSGSTARTRESPONSE._serialized_end=373
  _MSGUPDATEDETAILSRESPONSE._serialized_start=375
  _MSGUPDATEDETAILSRESPONSE._serialized_end=401
  _MSGENDRESPONSE._serialized_start=403
  _MSGENDRESPONSE._serialized_end=419
  _MSGSERVICE._serialized_start=422
  _MSGSERVICE._serialized_end=719
# @@protoc_insertion_point(module_scope)



from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ["deposit", "inactive_duration", "max_gigabyte_prices", "max_hourly_prices", "max_lease_hours", "max_leases", "min_gigabyte_prices", "min_hourly_prices", "min_lease_hours", "revenue_share"]
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    INACTIVE_DURATION_FIELD_NUMBER: _ClassVar[int]
    MAX_GIGABYTE_PRICES_FIELD_NUMBER: _ClassVar[int]
    MAX_HOURLY_PRICES_FIELD_NUMBER: _ClassVar[int]
    MAX_LEASES_FIELD_NUMBER: _ClassVar[int]
    MAX_LEASE_HOURS_FIELD_NUMBER: _ClassVar[int]
    MIN_GIGABYTE_PRICES_FIELD_NUMBER: _ClassVar[int]
    MIN_HOURLY_PRICES_FIELD_NUMBER: _ClassVar[int]
    MIN_LEASE_HOURS_FIELD_NUMBER: _ClassVar[int]
    REVENUE_SHARE_FIELD_NUMBER: _ClassVar[int]
    deposit: _coin_pb2.Coin
    inactive_duration: _duration_pb2.Duration
    max_gigabyte_prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    max_hourly_prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    max_lease_hours: int
    max_leases: int
    min_gigabyte_prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    min_hourly_prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    min_lease_hours: int
    revenue_share: str
    def __init__(self, deposit: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ..., inactive_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., max_gigabyte_prices: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., min_gigabyte_prices: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., max_hourly_prices: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., min_hourly_prices: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., max_lease_hours: _Optional[int] = ..., min_lease_hours: _Optional[int] = ..., max_leases: _Optional[int] = ..., revenue_share: _Optional[str] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.crypto.multisig.v1beta1 import multisig_pb2 as _multisig_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from cosmos.tx.signing.v1beta1 import signing_pb2 as _signing_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AuthInfo(_message.Message):
    __slots__ = ["fee", "signer_infos"]
    FEE_FIELD_NUMBER: _ClassVar[int]
    SIGNER_INFOS_FIELD_NUMBER: _ClassVar[int]
    fee: Fee
    signer_infos: _containers.RepeatedCompositeFieldContainer[SignerInfo]
    def __init__(self, signer_infos: _Optional[_Iterable[_Union[SignerInfo, _Mapping]]] = ..., fee: _Optional[_Union[Fee, _Mapping]] = ...) -> None: ...

class Fee(_message.Message):
    __slots__ = ["amount", "gas_limit", "granter", "payer"]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    GAS_LIMIT_FIELD_NUMBER: _ClassVar[int]
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    PAYER_FIELD_NUMBER: _ClassVar[int]
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    gas_limit: int
    granter: str
    payer: str
    def __init__(self, amount: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., gas_limit: _Optional[int] = ..., payer: _Optional[str] = ..., granter: _Optional[str] = ...) -> None: ...

class ModeInfo(_message.Message):
    __slots__ = ["multi", "single"]
    class Multi(_message.Message):
        __slots__ = ["bitarray", "mode_infos"]
        BITARRAY_FIELD_NUMBER: _ClassVar[int]
        MODE_INFOS_FIELD_NUMBER: _ClassVar[int]
        bitarray: _multisig_pb2.CompactBitArray
        mode_infos: _containers.RepeatedCompositeFieldContainer[ModeInfo]
        def __init__(self, bitarray: _Optional[_Union[_multisig_pb2.CompactBitArray, _Mapping]] = ..., mode_infos: _Optional[_Iterable[_Union[ModeInfo, _Mapping]]] = ...) -> None: ...
    class Single(_message.Message):
        __slots__ = ["mode"]
        MODE_FIELD_NUMBER: _ClassVar[int]
        mode: _signing_pb2.SignMode
        def __init__(self, mode: _Optional[_Union[_signing_pb2.SignMode, str]] = ...) -> None: ...
    MULTI_FIELD_NUMBER: _ClassVar[int]
    SINGLE_FIELD_NUMBER: _ClassVar[int]
    multi: ModeInfo.Multi
    single: ModeInfo.Single
    def __init__(self, single: _Optional[_Union[ModeInfo.Single, _Mapping]] = ..., multi: _Optional[_Union[ModeInfo.Multi, _Mapping]] = ...) -> None: ...

class SignDoc(_message.Message):
    __slots__ = ["account_number", "auth_info_bytes", "body_bytes", "chain_id"]
    ACCOUNT_NUMBER_FIELD_NUMBER: _ClassVar[int]
    AUTH_INFO_BYTES_FIELD_NUMBER: _ClassVar[int]
    BODY_BYTES_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    account_number: int
    auth_info_bytes: bytes
    body_bytes: bytes
    chain_id: str
    def __init__(self, body_bytes: _Optional[bytes] = ..., auth_info_bytes: _Optional[bytes] = ..., chain_id: _Optional[str] = ..., account_number: _Optional[int] = ...) -> None: ...

class SignerInfo(_message.Message):
    __slots__ = ["mode_info", "public_key", "sequence"]
    MODE_INFO_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    mode_info: ModeInfo
    public_key: _any_pb2.Any
    sequence: int
    def __init__(self, public_key: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., mode_info: _Optional[_Union[ModeInfo, _Mapping]] = ..., sequence: _Optional[int] = ...) -> None: ...

class Tx(_message.Message):
    __slots__ = ["auth_info", "body", "signatures"]
    AUTH_INFO_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    auth_info: AuthInfo
    body: TxBody
    signatures: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, body: _Optional[_Union[TxBody, _Mapping]] = ..., auth_info: _Optional[_Union[AuthInfo, _Mapping]] = ..., signatures: _Optional[_Iterable[bytes]] = ...) -> None: ...

class TxBody(_message.Message):
    __slots__ = ["extension_options", "memo", "messages", "non_critical_extension_options", "timeout_height"]
    EXTENSION_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    MEMO_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    NON_CRITICAL_EXTENSION_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    extension_options: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    memo: str
    messages: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    non_critical_extension_options: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    timeout_height: int
    def __init__(self, messages: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ..., memo: _Optional[str] = ..., timeout_height: _Optional[int] = ..., extension_options: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ..., non_critical_extension_options: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ...) -> None: ...

class TxRaw(_message.Message):
    __slots__ = ["auth_info_bytes", "body_bytes", "signatures"]
    AUTH_INFO_BYTES_FIELD_NUMBER: _ClassVar[int]
    BODY_BYTES_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    auth_info_bytes: bytes
    body_bytes: bytes
    signatures: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, body_bytes: _Optional[bytes] = ..., auth_info_bytes: _Optional[bytes] = ..., signatures: _Optional[_Iterable[bytes]] = ...) -> None: ...



from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgCreateRequest(_message.Message):
    __slots__ = ["bytes", "prices", "validity"]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    PRICES_FIELD_NUMBER: _ClassVar[int]
    VALIDITY_FIELD_NUMBER: _ClassVar[int]
    bytes: str
    prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    validity: _duration_pb2.Duration
    def __init__(self, prices: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., validity: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., bytes: _Optional[str] = ..., **kwargs) -> None: ...

class MsgCreateResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgLinkNodeRequest(_message.Message):
    __slots__ = ["address", "id"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    id: int
    def __init__(self, id: _Optional[int] = ..., address: _Optional[str] = ..., **kwargs) -> None: ...

class MsgLinkNodeResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgSubscribeRequest(_message.Message):
    __slots__ = ["denom", "id"]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    denom: str
    id: int
    def __init__(self, id: _Optional[int] = ..., denom: _Optional[str] = ..., **kwargs) -> None: ...

class MsgSubscribeResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgUnlinkNodeRequest(_message.Message):
    __slots__ = ["address", "id"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    id: int
    def __init__(self, id: _Optional[int] = ..., address: _Optional[str] = ..., **kwargs) -> None: ...

class MsgUnlinkNodeResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgUpdateStatusRequest(_message.Message):
    __slots__ = ["id", "status"]
    FROM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    id: int
    status: _status_pb2.Status
    def __init__(self, id: _Optional[int] = ..., status: _Optional[_Union[_status_pb2.Status, str]] = ..., **kwargs) -> None: ...

class MsgUpdateStatusResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from cosmos.gov.v1beta1 import gov_pb2 as _gov_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryDepositRequest(_message.Message):
    __slots__ = ["depositor", "proposal_id"]
    DEPOSITOR_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    depositor: str
    proposal_id: int
    def __init__(self, proposal_id: _Optional[int] = ..., depositor: _Optional[str] = ...) -> None: ...

class QueryDepositResponse(_message.Message):
    __slots__ = ["deposit"]
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    deposit: _gov_pb2.Deposit
    def __init__(self, deposit: _Optional[_Union[_gov_pb2.Deposit, _Mapping]] = ...) -> None: ...

class QueryDepositsRequest(_message.Message):
    __slots__ = ["pagination", "proposal_id"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    proposal_id: int
    def __init__(self, proposal_id: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryDepositsResponse(_message.Message):
    __slots__ = ["deposits", "pagination"]
    DEPOSITS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    deposits: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Deposit]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, deposits: _Optional[_Iterable[_Union[_gov_pb2.Deposit, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryParamsRequest(_message.Message):
    __slots__ = ["params_type"]
    PARAMS_TYPE_FIELD_NUMBER: _ClassVar[int]
    params_type: str
    def __init__(self, params_type: _Optional[str] = ...) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ["deposit_params", "tally_params", "voting_params"]
    DEPOSIT_PARAMS_FIELD_NUMBER: _ClassVar[int]
    TALLY_PARAMS_FIELD_NUMBER: _ClassVar[int]
    VOTING_PARAMS_FIELD_NUMBER: _ClassVar[int]
    deposit_params: _gov_pb2.DepositParams
    tally_params: _gov_pb2.TallyParams
    voting_params: _gov_pb2.VotingParams
    def __init__(self, voting_params: _Optional[_Union[_gov_pb2.VotingParams, _Mapping]] = ..., deposit_params: _Optional[_Union[_gov_pb2.DepositParams, _Mapping]] = ..., tally_params: _Optional[_Union[_gov_pb2.TallyParams, _Mapping]] = ...) -> None: ...

class QueryProposalRequest(_message.Message):
    __slots__ = ["proposal_id"]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    def __init__(self, proposal_id: _Optional[int] = ...) -> None: ...

class QueryProposalResponse(_message.Message):
    __slots__ = ["proposal"]
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    proposal: _gov_pb2.Proposal
    def __init__(self, proposal: _Optional[_Union[_gov_pb2.Proposal, _Mapping]] = ...) -> None: ...

class QueryProposalsRequest(_message.Message):
    __slots__ = ["depositor", "pagination", "proposal_status", "voter"]
    DEPOSITOR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_STATUS_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    depositor: str
    pagination: _pagination_pb2.PageRequest
    proposal_status: _gov_pb2.ProposalStatus
    voter: str
    def __init__(self, proposal_status: _Optional[_Union[_gov_pb2.ProposalStatus, str]] = ..., voter: _Optional[str] = ..., depositor: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryProposalsResponse(_message.Message):
    __slots__ = ["pagination", "proposals"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PROPOSALS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    proposals: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Proposal]
    def __init__(self, proposals: _Optional[_Iterable[_Union[_gov_pb2.Proposal, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryTallyResultRequest(_message.Message):
    __slots__ = ["proposal_id"]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    def __init__(self, proposal_id: _Optional[int] = ...) -> None: ...

class QueryTallyResultResponse(_message.Message):
    __slots__ = ["tally"]
    TALLY_FIELD_NUMBER: _ClassVar[int]
    tally: _gov_pb2.TallyResult
    def __init__(self, tally: _Optional[_Union[_gov_pb2.TallyResult, _Mapping]] = ...) -> None: ...

class QueryVoteRequest(_message.Message):
    __slots__ = ["proposal_id", "voter"]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    voter: str
    def __init__(self, proposal_id: _Optional[int] = ..., voter: _Optional[str] = ...) -> None: ...

class QueryVoteResponse(_message.Message):
    __slots__ = ["vote"]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    vote: _gov_pb2.Vote
    def __init__(self, vote: _Optional[_Union[_gov_pb2.Vote, _Mapping]] = ...) -> None: ...

class QueryVotesRequest(_message.Message):
    __slots__ = ["pagination", "proposal_id"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    proposal_id: int
    def __init__(self, proposal_id: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryVotesResponse(_message.Message):
    __slots__ = ["pagination", "votes"]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    VOTES_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    votes: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Vote]
    def __init__(self, votes: _Optional[_Iterable[_Union[_gov_pb2.Vote, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.session.v2 import proof_pb2 as _proof_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgEndRequest(_message.Message):
    __slots__ = ["id", "rating"]
    FROM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    RATING_FIELD_NUMBER: _ClassVar[int]
    id: int
    rating: int
    def __init__(self, id: _Optional[int] = ..., rating: _Optional[int] = ..., **kwargs) -> None: ...

class MsgEndResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgStartRequest(_message.Message):
    __slots__ = ["address", "id"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    id: int
    def __init__(self, id: _Optional[int] = ..., address: _Optional[str] = ..., **kwargs) -> None: ...

class MsgStartResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MsgUpdateDetailsRequest(_message.Message):
    __slots__ = ["proof", "signature"]
    FROM_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    proof: _proof_pb2.Proof
    signature: bytes
    def __init__(self, proof: _Optional[_Union[_proof_pb2.Proof, _Mapping]] = ..., signature: _Optional[bytes] = ..., **kwargs) -> None: ...

class MsgUpdateDetailsResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...
